UMA-ASE Web Interface

## Input Details

Select Geometry Input file No file selected
Charge
Spin Multiplicity
MLFF Checkpoint
MLFF Task
Run Type
Single Point GeoOpt Frequencies
Optimizer
Force (eV/Å)
Max Iter

Vib Analysis Settings

Temperature (K)
Pressure (Pa)

### Summary

    No structure loaded.

## Calculate

## Results

Upload a structure and run a job to see results here.

## Input Details

Geometry Input file No file selected
Charge
Spin Multiplicity

### Summary

    No structure loaded.

## 3D Visualizer

The visualizer automatically loads the geometry selected on the Actions tab. You can also open a file directly below.

Load a structure file